@@ -23,12 +23,10 @@ import java.io.FileOutputStream;
 import java.io.FileReader;
 import java.io.IOException;
 import java.io.InputStream;
-import java.io.InputStreamReader;
 import java.lang.reflect.Field;
 import java.lang.reflect.Modifier;
 import java.net.HttpURLConnection;
 import java.net.IDN;
-import java.net.MalformedURLException;
 import java.net.URL;
 import java.text.SimpleDateFormat;
 import java.util.Date;
@@ -49,12 +47,13 @@ import junit.framework.TestCase;
 /**
  * Tests for the DomainValidator.
  *
- * @version $Revision: 1712853 $
+ * @version $Revision: 1739361 $
  */
 public class DomainValidatorTest extends TestCase {
 
     private DomainValidator validator;
 
+    @Override
     public void setUp() {
         validator = DomainValidator.getInstance();
         DomainValidator.clearTLDOverrides(); // N.B. this clears the inUse flag, allowing overrides
@@ -299,6 +298,48 @@ public class DomainValidatorTest extends TestCase {
         assertTrue(sorted);
     }
 
+    public void testEnumIsPublic() {
+        assertTrue(Modifier.isPublic(DomainValidator.ArrayType.class.getModifiers()));
+    }
+
+    public void testUpdateBaseArrays() {
+        try {
+            DomainValidator.updateTLDOverride(ArrayType.COUNTRY_CODE_RO, new String[]{"com"});
+            fail("Expected IllegalArgumentException");
+        } catch (IllegalArgumentException iae) {
+            // expected
+        }
+        try {
+            DomainValidator.updateTLDOverride(ArrayType.GENERIC_RO, new String[]{"com"});
+            fail("Expected IllegalArgumentException");
+        } catch (IllegalArgumentException iae) {
+            // expected
+        }
+        try {
+            DomainValidator.updateTLDOverride(ArrayType.INFRASTRUCTURE_RO, new String[]{"com"});
+            fail("Expected IllegalArgumentException");
+        } catch (IllegalArgumentException iae) {
+            // expected
+        }
+        try {
+            DomainValidator.updateTLDOverride(ArrayType.LOCAL_RO, new String[]{"com"});
+            fail("Expected IllegalArgumentException");
+        } catch (IllegalArgumentException iae) {
+            // expected
+        }
+    }
+
+    public void testGetArray() {
+        assertNotNull(DomainValidator.getTLDEntries(ArrayType.COUNTRY_CODE_MINUS));
+        assertNotNull(DomainValidator.getTLDEntries(ArrayType.COUNTRY_CODE_PLUS));
+        assertNotNull(DomainValidator.getTLDEntries(ArrayType.GENERIC_MINUS));
+        assertNotNull(DomainValidator.getTLDEntries(ArrayType.GENERIC_PLUS));
+        assertNotNull(DomainValidator.getTLDEntries(ArrayType.COUNTRY_CODE_RO));
+        assertNotNull(DomainValidator.getTLDEntries(ArrayType.GENERIC_RO));
+        assertNotNull(DomainValidator.getTLDEntries(ArrayType.INFRASTRUCTURE_RO));
+        assertNotNull(DomainValidator.getTLDEntries(ArrayType.LOCAL_RO));
+    }
+
     public void testUpdateCountryCode() {
         assertFalse(validator.isValidCountryCodeTld("com")); // cannot be valid
         DomainValidator.updateTLDOverride(ArrayType.COUNTRY_CODE_PLUS, new String[]{"com"});
@@ -353,7 +394,7 @@ public class DomainValidatorTest extends TestCase {
             return;
         }
         Set<String> ianaTlds = new HashSet<String>(); // keep for comparison with array contents
-        DomainValidator dv = DomainValidator.getInstance();;
+        DomainValidator dv = DomainValidator.getInstance();
         File txtFile = new File("target/tlds-alpha-by-domain.txt");
         long timestamp = download(txtFile, "http://data.iana.org/TLD/tlds-alpha-by-domain.txt", 0L);
         final File htmlFile = new File("target/tlds-alpha-by-domain.html");
@@ -387,7 +428,7 @@ public class DomainValidatorTest extends TestCase {
                     unicodeTld = asciiTld;
                 }
                 if (!dv.isValidTld(asciiTld)) {
-                    String [] info = (String[]) htmlInfo.get(asciiTld);
+                    String [] info = htmlInfo.get(asciiTld);
                     if (info != null) {
                         String type = info[0];
                         String comment = info[1];
@@ -419,8 +460,10 @@ public class DomainValidatorTest extends TestCase {
         // List html entries not in TLD text list
         for(String key : (new TreeMap<String, String[]>(htmlInfo)).keySet()) {
             if (!ianaTlds.contains(key)) {
-                if (!isNotInRootZone(key)) {
-                    System.err.println("Expected to find text entry for html: "+key);                    
+                if (isNotInRootZone(key)) {
+                    System.out.println("INFO: HTML entry not yet in root zone: "+key);
+                } else {
+                    System.err.println("WARN: Expected to find text entry for html: "+key);
                 }
             }
         }
@@ -552,14 +595,21 @@ public class DomainValidatorTest extends TestCase {
         return f.lastModified();
     }
 
+    /**
+     * Check whether the domain is in the root zone currently.
+     * Reads the URL http://www.iana.org/domains/root/db/*domain*.html
+     * (using a local disk cache)
+     * and checks for the string "This domain is not present in the root zone at this time."
+     * @param domain the domain to check
+     * @return true if the string is found
+     */
     private static boolean isNotInRootZone(String domain) {
         String tldurl = "http://www.iana.org/domains/root/db/" + domain + ".html";
-        HttpURLConnection hc = null;
+        File rootCheck = new File("target","tld_" + domain + ".html");
         BufferedReader in = null;
         try {
-            hc = (HttpURLConnection) new URL(tldurl).openConnection();
-            in = new BufferedReader(
-                    new InputStreamReader(hc.getInputStream()));
+            download(rootCheck, tldurl, 0L);
+            in = new BufferedReader(new FileReader(rootCheck));
             String inputLine;
             while ((inputLine = in.readLine()) != null) {
                 if (inputLine.contains("This domain is not present in the root zone at this time.")) {
@@ -567,13 +617,9 @@ public class DomainValidatorTest extends TestCase {
                 }
             }
             in.close();        
-        } catch (MalformedURLException e) {
         } catch (IOException e) {
         } finally {
             closeQuietly(in);
-            if (hc != null) {
-                hc.disconnect();
-            }
         }
         return false;
     }
